@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+# Copyright (c) 2009-2012, Erkan Ozgur Yilmaz
+# 
+# This module is part of oyProjectManager and is released under the BSD 2
+# License: http://www.opensource.org/licenses/BSD-2-Clause
 
 import os
 import logging
@@ -6,144 +10,53 @@ import logging
 logger = logging.getLogger(__name__)
 
 class Config(object):
-    """config abstraction
+    """Config abstraction
     
-    Idea comes from Sphinx config
+    Idea is coming from Sphinx config.
     
+    Holds system wide configuration variables. See
+    `configuring oyProjectManager`_ for more detail.
     
-    **config.py File**
-    
-    oyProjectManager uses the ``config.py`` to let one to customize the system
-    config.
-    
-    The ``config.py`` file is searched in a couple of places through the
-    system:
-        
-        * under "~/.oypmrc/" directory
-        * under "$OYPROJECTMANAGER_PATH"
-    
-    The first path is a folder in the users home dir. The second one is a path
-    defined by the ``OYPROJECTMANAGER_PATH`` environment variable.
-    
-    Defining the ``config.py`` by using the environment variable gives the most
-    customizable and consistent setup through the studio. You can set
-    ``OYPROJECTMANAGER_PATH`` to a shared folder in your fileserver where all
-    the users can access.
-    
-    Because, ``config.py`` is a regular Python code which is executed by
-    oyProjectManager, you can do anything you were doing in a normal Python
-    script. This is very handy if you have another source of information which
-    is reachable by a Python script.
-    
-    In config.py you can:
-      
-      * Add new users
-      * Customize default project structure
-      * Customize file naming convention
-      * Customize path naming convention
-      * Customize the database file name
-      * Customize server paths
-      * Customize environments (host programs running oyProjectManager)
-      * and many more
-    
-    If there is no ``OYPROJECTMANAGER_PATH`` variable in your current
-    environment or it is not showing an existing path or there is no
-    ``config.py`` file the system will use the system defaults and it is
-    probably not going to work efficiently.
-    
-    Sample usage is::
-    
-        from oyProjectManager import config
-        conf = config.Config()
-        
-        print conf.database_file_name # will return .metadata.db
-        
-        # print all the user names defined in the config.py
-        for user in conf.users:
-            print user.name
-    
-    **About the Users**
-    The users in the oyProjectManager is held in the config file as a python
-    dictionary. You can add or remove users::
-      
-      users_data = [{"name": "Erkan Ozgur Yilmaz",
-                     "initials":"eoy",
-                     "email": "eoyilmaz@company.com"}]
-    
-    As seen in the above example the ``users_data`` variable is a python list
-    holding python dictionary, and the dictionary has keys like name, initials
-    and email.
-    
-    The users are created from the ``config.py`` file for UI, but the user data
-    will be hold in the project based database (.metadata.db) if the user
-    created a data for that project. So one project can have more users then
-    others. ``config.users`` will return a list of
-    :class:`~oyProjectManager.core.models.User` instances.
-    
-    **Config Variables**
-    
-    TODO: Add explanation of each variable
-    
-    database_url = "sqlite:///$REPO/.metadata.db"
-    shot_number_prefix = "SH"
-    shot_number_padding = 3
-    
-    rev_number_prefix = "r"
-    rev_number_padding = 2
-    
-    ver_number_prefix = "v"
-    ver_number_padding = 3
-    
-    fps = 25
-    resolution_width = 1920
-    resolution_height = 1080
-    resolution_pixel_aspect = 1.0
-    
-    take_name = "MAIN"
-    
-    users_data = [{"name": "Administrator", "initials": "adm"}]
-    
-    repository = [
-            {
-                "name": "Default Projects Repository"
-                "windows_path": "~/Projects",
-                "linux_path": "~/Projects",
-                "osx_path": "~/Projects"
-            }
-    ]
-    
-    environments = [
-            {
-                "name":"Maya",
-                "extensions":["ma", "mb"]
-            },
-            {
-                "name":"Houdini",
-                "extensions":["hip"]
-            },
-            {
-                "name":"Nuke",
-                "extensions": ["nk"],
-            },
-            {
-                "name":"Photoshop",
-                "extensions": ["psd", "pdd"],
-                "export_extensions": ["tif", "tga", "bmp", "jpg", "iff"],
-            },
-            {
-                "name":"3DEqualizer",
-                "extensions": ["3te"]
-            }
-        ]
-        
-    project_structure = 
-    
-    version_types =  
+    .. _configuring oyProjectManager: ../configure.html
     """
     
     default_config_values = dict(
         
-        database_url = "sqlite:///$REPO/project_manager.db",
+        database_url = "sqlite:///$OYPROJECTMANAGER_PATH/project_manager.db",
+        
+        status_list = [
+            'WTS',
+            'WIP',
+            'REV',
+            'APP',
+            'CMP'
+        ],
+        
+        status_list_long_names = [
+            'Waiting To Start',
+            'Work In Progress',
+            'For Review',
+            'Approved',
+            'Completed'
+        ],
+        
+        status_bg_colors = [
+            (192,  80,  77), #WTS
+            (255, 192,   0), #WIP
+            ( 89, 141, 213), #REV
+            (155, 187,  89), #APP
+            (155, 187,  89), #CMP
+        ],
+        
+        status_fg_colors = [
+            (255, 255, 255), #WTS
+            (  0,   0,   0), #WIP
+            (  0,   0,   0), #REV
+            (  0,   0,   0), #APP
+            (  0,   0,   0), #CMP
+        ],
+        
+        sequence_format = "%h%p%t %R",
         
         shot_number_prefix = "SH",
         shot_number_padding = 3,
@@ -155,11 +68,9 @@ class Config(object):
         ver_number_padding = 3,
         
         default_fps = 25,
-#        resolution_width = 1920,
-#        resolution_height = 1080,
-#        resolution_pixel_aspect = 1.0,
         
-        default_take_name = "MAIN",
+        default_asset_type_name = "Generic",
+        default_take_name = "Main",
         
         users_data = [{"name": "Administrator", "initials": "adm"}],
         
@@ -172,7 +83,11 @@ class Config(object):
             "linux_path": "~/Projects",
             "osx_path": "~/Projects"
         },
-        
+
+
+        file_size_format = "%.2f MB",
+        time_format = '%d.%m.%Y %H:%M',
+
         environments = [
             {
                 "name":"Maya",
@@ -194,6 +109,10 @@ class Config(object):
             {
                 "name":"3DEqualizer",
                 "extensions": ["3te"]
+            },
+            {
+                "name":"Fusion",
+                "extensions": ["comp"]
             }
         ],
         
@@ -232,30 +151,41 @@ class Config(object):
             {{seq_path}}/Edit/Sound
             {{seq_path}}/References/Artworks
             {{seq_path}}/References/Text/Scenario
+            {{seq_path}}/References/Text/Brief
             {{seq_path}}/References/Photos_Images
             {{seq_path}}/References/Videos
             {{seq_path}}/References/Others
-            {{seq_path}}/Others
-            {{seq_path}}/Others/assets
-            {{seq_path}}/Others/clips
-            {{seq_path}}/Others/data
-            {{seq_path}}/Others/fur
-            {{seq_path}}/Others/fur/furAttrMap
-            {{seq_path}}/Others/fur/furEqualMap
-            {{seq_path}}/Others/fur/furFiles
-            {{seq_path}}/Others/fur/furImages
-            {{seq_path}}/Others/fur/furShadowMap
-            {{seq_path}}/Others/mel
-            {{seq_path}}/Others/particles
+            {{seq_path}}/References/Storyboard
+            {% for shot in sequence.shots %}
+                {{seq_path}}/Shots/{{shot.code}}
+                {{seq_path}}/Shots/{{shot.code}}/Plate
+                {{seq_path}}/Shots/{{shot.code}}/Reference
+                {{seq_path}}/Shots/{{shot.code}}/Texture
+            {% endfor %}
+        {% endfor %}
+        {% for asset in project.assets%}
+            {% set asset_path = project.full_path + '/Assets/' + asset.type + '/' + asset.code %}
+            {{asset_path}}/Texture
+            {{asset_path}}/Reference
         {% endfor %}
         """,
         
+        asset_thumbnail_path = "{{project.code}}/Assets/{{asset.type}}/{{asset.code}}/Thumbnail",
+        asset_thumbnail_filename = "{{asset.code}}_thumbnail.{{extension}}",
+        
+        shot_thumbnail_path = "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{shot.code}}/Thumbnail",
+        shot_thumbnail_filename = "{{shot.code}}_thumbnail.{{extension}}",
+        
+        thumbnail_format = "jpg",
+        thumbnail_quality = 70,
+        thumbnail_size = [320, 180],
+        
         version_types = [
             {
                 "name": "Animation",
                 "code": "Anim",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
@@ -265,7 +195,7 @@ class Config(object):
                 "name": "Camera",
                 "code": "Cam",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
@@ -275,45 +205,39 @@ class Config(object):
                 "name": "Composition",
                 "code": "Comp",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
-                "output_path": "{{version._path}}/Output/{{version.take_name}}",
-                "extra_folders": "",
-                "environments": ["Nuke"],
-                "type_for": "Shot"
-            },
-            {
-                "name": "Edit",
-                "code": "Edit",
-                "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
-                "output_path": "{{version._path}}/Output/{{version.take_name}}",
-                "extra_folders": "",
-                "environments": ["Nuke"],
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
+                "output_path": "{{version._path}}/Output/{{version.take_name}}/v{{'%03d'|format(version.version_number)}}",
+                "extra_folders": "{{version.path}}/Elements",
+                "environments": ["Nuke", "Fusion"],
                 "type_for": "Shot"
             },
+#            {
+#                "name": "Edit",
+#                "code": "Edit",
+#                "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
+#                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
+#                "output_path": "{{version._path}}/Output/{{version.take_name}}",
+#                "extra_folders": "",
+#                "environments": ["Nuke", "Fusion"],
+#                "type_for": "Shot"
+#            },
             {
                 "name":"FX",
                 "code": "FX",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": """{{version.path}}/anim
                         {{version.path}}/cache
-                        {{version.path}}/exports
-                        {{version.path}}/fx_scenes
-                        {{version.path}}/maps
-                        {{version.path}}/misc
-                        {{version.path}}/obj
-                        {{version.path}}/sim_in
-                        {{version.path}}/sim_out""",
+                        {{version.path}}/exports""",
                 "environments": ["Maya", "Houdini"],
                 "type_for": "Shot"
             },
             {
                 "name":"Model",
                 "code": "Model",
-                "path": "{{project.code}}/Assets/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "path": "{{project.code}}/Assets/{{asset.type}}/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
@@ -322,18 +246,18 @@ class Config(object):
             {
                 "name": "Other",
                 "code": "Other",
-                "path": "{{project.code}}/Others/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "path": "{{project.code}}/Assets/{{asset.type}}/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
-                "environments": ["Maya", "Houdini", "Nuke"],
+                "environments": ["Maya", "Houdini", "Nuke", "Fusion", "Photoshop"],
                 "type_for": "Asset"
             },
             {
                 "name": "Previs",
                 "code": "Previs",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
@@ -343,7 +267,7 @@ class Config(object):
                 "name": "Lighting",
                 "code": "Lighting",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
@@ -352,58 +276,68 @@ class Config(object):
             {
                 "name": "Rig",
                 "code": "Rig",
-                "path": "{{project.code}}/Assets/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "path": "{{project.code}}/Assets/{{asset.type}}/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
                 "type_for": "Asset"
             },
             {
-                "name": "Scene Assembly",
-                "code": "ScnAss",
+                "name": "Roto",
+                "code": "Roto",
+                "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
+                "output_path": "{{version._path}}/Output/{{version.take_name}}",
+                "extra_folders": "",
+                "environments": ["Nuke", "Fusion"],
+                "type_for": "Shot"
+            },
+            {
+                "name": "Layout",
+                "code": "Layout",
                 "path":"{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
                 "type_for": "Shot"
             },
             {
-                "name": "Matte Paint",
+                "name": "Matte",
                 "code": "Matte",
-                "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/PAINTINGS/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Photoshop"],
                 "type_for": "Shot"
             },
             {
-                "name": "Texture Paint",
+                "name": "Texture",
                 "code": "Texture",
-                "path": "{{project.code}}/Assets/{{version.base_name}}/PAINTINGS/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "path": "{{project.code}}/Assets/{{asset.type}}/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
-                "environments": ["Photoshop"],
+                "environments": ["Photoshop", "Nuke", "Fusion"],
                 "type_for": "Asset",
             },
             {
                 "name": "Illustration",
                 "code": "Illust",
-                "path": "{{project.code}}/Assets/{{version.base_name}}/PAINTINGS/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "path": "{{project.code}}/Assets/{{asset.type}}/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Photoshop"],
                 "type_for": "Asset"
             },
             {
-                "name": "Shading",
-                "code": "Shading",
-                "path": "{{project.code}}/Assets/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "name": "Look Development",
+                "code": "LookDev",
+                "path": "{{project.code}}/Assets/{{asset.type}}/{{version.base_name}}/{{type.code}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["Maya", "Houdini"],
@@ -413,13 +347,71 @@ class Config(object):
                 "name": "Match Move",
                 "code": "MM",
                 "path": "{{project.code}}/Sequences/{{sequence.code}}/Shots/{{version.base_name}}/{{type.code}}",
-                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}_{{version.created_by.initials}}{{version.extension}}",
+                "filename": "{{version.base_name}}_{{version.take_name}}_{{type.code}}_v{{'%03d'|format(version.version_number)}}{{version.extension}}",
                 "output_path": "{{version._path}}/Output/{{version.take_name}}",
                 "extra_folders": "",
                 "environments": ["3DEqualizer"],
                 "type_for": "Shot"
             }
-        ]
+        ],
+        
+        maya_workspace_file_content = """workspace -fr "3dPaintTextures" ".mayaFiles/sourceimages/3dPaintTextures/";
+workspace -fr "Adobe(R) Illustrator(R)" ".mayaFiles/data/";
+workspace -fr "aliasWire" ".mayaFiles/data/";
+workspace -fr "animImport" ".mayaFiles/data/";
+workspace -fr "animExport" ".mayaFiles/data/";
+workspace -fr "audio" ".mayaFiles/sound/";
+workspace -fr "autoSave" ".mayaFiles/autosave/";
+workspace -fr "clips" ".mayaFiles/clips/";
+workspace -fr "DAE_FBX" ".mayaFiles/data/";
+workspace -fr "DAE_FBX export" ".mayaFiles/data/";
+workspace -fr "depth" ".mayaFiles/renderData/depth/";
+workspace -fr "diskCache" ".mayaFiles/cache/";
+workspace -fr "DXF" ".mayaFiles/data/";
+workspace -fr "DXF export" ".mayaFiles/data/";
+workspace -fr "DXF_FBX" ".mayaFiles/data/";
+workspace -fr "DXF_FBX export" ".mayaFiles/data/";
+workspace -fr "eps" ".mayaFiles/data/";
+workspace -fr "EPS" ".mayaFiles/data/";
+workspace -fr "FBX" ".mayaFiles/data/";
+workspace -fr "FBX export" ".mayaFiles/data/";
+workspace -fr "fluidCache" ".mayaFiles/cache/fluid/";
+workspace -fr "furAttrMap" ".mayaFiles/renderData/fur/furAttrMap/";
+workspace -fr "furEqualMap" ".mayaFiles/renderData/fur/furEqualMap/";
+workspace -fr "furFiles" ".mayaFiles/renderData/fur/furFiles/";
+workspace -fr "furImages" ".mayaFiles/renderData/fur/furImages/";
+workspace -fr "furShadowMap" ".mayaFiles/renderData/fur/furShadowMap/";
+workspace -fr "IGES" ".mayaFiles/data/";
+workspace -fr "IGESexport" ".mayaFiles/data/";
+workspace -fr "illustrator" ".mayaFiles/data/";
+workspace -fr "image" ".mayaFiles/images/";
+workspace -fr "images" ".mayaFiles/images/";
+workspace -fr "iprImages" ".mayaFiles/renderData/iprImages/";
+workspace -fr "lights" ".mayaFiles/renderData/shaders/";
+workspace -fr "mayaAscii" ".mayaFiles/scenes/";
+workspace -fr "mayaBinary" ".mayaFiles/scenes/";
+workspace -fr "mel" ".mayaFiles/scripts/";
+workspace -fr "mentalray" ".mayaFiles/renderData/mentalray/";
+workspace -fr "mentalRay" ".mayaFiles/renderData/mentalray";
+workspace -fr "move" ".mayaFiles/data/";
+workspace -fr "movie" ".mayaFiles/movies/";
+workspace -fr "OBJ" ".mayaFiles/data/";
+workspace -fr "OBJexport" ".mayaFiles/data/";
+workspace -fr "offlineEdit" ".mayaFiles/scenes/edits/";
+workspace -fr "particles" ".mayaFiles/particles/";
+workspace -fr "renderData" ".mayaFiles/renderData/";
+workspace -fr "renderScenes" ".mayaFiles/scenes/";
+workspace -fr "RIB" ".mayaFiles/data/";
+workspace -fr "RIBexport" ".mayaFiles/data/";
+workspace -fr "scene" ".mayaFiles/scenes/";
+workspace -fr "scripts" ".mayaFiles/scripts/";
+workspace -fr "shaders" ".mayaFiles/renderData/shaders/";
+workspace -fr "sound" ".mayaFiles/sound/";
+workspace -fr "sourceImages" ".mayaFiles/sourceimages/";
+workspace -fr "templates" ".mayaFiles/assets/";
+workspace -fr "textures" ".mayaFiles/images/";
+workspace -fr "translatorData" ".mayaFiles/data/";
+"""
     )
     
     def __init__(self):
