@@ -10,8 +10,9 @@ import os
 from pymel import core as pm
 
 from oyProjectManager import conf
-from oyProjectManager.core.models import Repository, EnvironmentBase
 from oyProjectManager import utils
+from oyProjectManager.models.entity import EnvironmentBase
+from oyProjectManager.models.repository import Repository
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.WARNING)
@@ -20,10 +21,6 @@ class Maya(EnvironmentBase):
     """the maya environment class
     """
     
-    # TODO: check for texture file paths and warn the user if there are
-    # textures with absolute paths which are not starting with the
-    # repo.server_path
-    
     name = "Maya"
     
     time_to_fps = {
@@ -75,6 +72,9 @@ class Maya(EnvironmentBase):
         It saves the given Version instance to the Version.full_path.
         """
         
+        # do not save if there are local files
+        self.check_external_files()
+        
         # set version extension to ma
         version.extension = '.ma'
         
@@ -88,29 +88,41 @@ class Maya(EnvironmentBase):
         
         # if the new workspace path is not matching the with the previous one
         # update the external paths to absolute version
+        logger.debug("current workspace: %s" % current_workspace_path)
+        logger.debug("next workspace: %s" % workspace_path)
+        
         if current_workspace_path != workspace_path:
             logger.debug("changing workspace detected!")
-            logger.debug("current workspace: %s" % current_workspace_path)
-            logger.debug("next workspace: %s" % workspace_path)
             logger.debug("converting paths to absolute, to be able to "
                          "preserve external paths")
             
             # replace external paths with absolute ones
             self.replace_external_paths(mode=1)
         
+        # create the workspace folders
         self.create_workspace_file(workspace_path)
+        
         # this sets the project
         pm.workspace.open(workspace_path)
         
+        # create workspace folders
+        self.create_workspace_folders(workspace_path)
+        
         # set scene fps
         self.set_fps(project.fps)
         
-        # set render resolution
         # only if the file is a new version
         if version.version_number == 1:
+            # set render resolution
             self.set_resolution(project.width, project.height,
                 project.pixel_aspect)
-        
+            # set the render range
+            if version.type.type_for == 'Shot':
+                self.set_frame_range(
+                    version.version_of.start_frame,
+                    version.version_of.end_frame
+                )
+                
         # set the render file name and version
         self.set_render_fileName(version)
         
@@ -134,15 +146,7 @@ class Maya(EnvironmentBase):
         )
         
         # update the reference list
-        # TODO: Why am I not using self.update_references_list here
-        reference_list = []
-        reference_info = self.get_referenced_versions()
-        for data in reference_info:
-            if data[0] not in reference_list:
-                reference_list.append(data[0])
-        
-        version.references = reference_list
-        version.save()
+        self.update_references_list(version)
         
         # append it to the recent file list
         self.append_to_recent_files(
@@ -158,12 +162,20 @@ class Maya(EnvironmentBase):
         # check if there is something selected
         if len(pm.ls(sl=True)) < 1:
             raise RuntimeError("There is nothing selected to export")
+
+        # do not save if there are local files
+        self.check_external_files()
         
         # set the extension to ma by default
         version.extension = '.ma'
         
         # create the folder if it doesn't exists
         utils.createFolder(version.path)
+
+        workspace_path = os.path.dirname(version.path)
+        
+        self.create_workspace_file(workspace_path)
+        self.create_workspace_folders(workspace_path)
         
         # export the file
         pm.exportSelected(version.full_path, type='mayaAscii')
@@ -180,7 +192,7 @@ class Maya(EnvironmentBase):
         
         It also updates the referenced Version on open.
         
-        :returns: list of :class:`~oyProjectManager.core.models.Version`
+        :returns: list of :class:`~oyProjectManager.models.version.Version`
           instances which are referenced in to the opened version and those
           need to be updated
         """
@@ -191,6 +203,9 @@ class Maya(EnvironmentBase):
         # set the project
         new_workspace = os.path.dirname(version.path)
 
+        #self.create_workspace_file(workspace_path)
+        #self.create_workspace_folders(workspace_path)
+        
         pm.workspace.open(new_workspace)
         
         # check for unsaved changes
@@ -217,10 +232,10 @@ class Maya(EnvironmentBase):
         # check the referenced assets for newer version
         to_update_list = self.check_referenced_versions()
         
-        for update_info in to_update_list:
-            version = update_info[0]
+        #for update_info in to_update_list:
+        #    version = update_info[0]
         
-        self.update_references_list()
+        self.update_references_list(version)
         
         return True, to_update_list
     
@@ -228,14 +243,14 @@ class Maya(EnvironmentBase):
         """Runs after opening a file
         """
         self.load_referenced_versions()
-        self.update_references_list()
+        self.update_references_list(version)
 
     def import_(self, version):
         """Imports the content of the given Version instance to the current
         scene.
         
         :param version: The desired
-          :class:`~oyProjectManager.core.models.Version` to be imported
+          :class:`~oyProjectManager.models.version.Version` to be imported
         """
         pm.importFile(version.full_path)
         
@@ -245,7 +260,7 @@ class Maya(EnvironmentBase):
         """References the given Version instance to the current Maya scene.
         
         :param version: The desired
-          :class:`~oyProjectManager.core.models.Version` instance to be
+          :class:`~oyProjectManager.models.version.Version` instance to be
           referenced.
         """
         
@@ -314,14 +329,14 @@ class Maya(EnvironmentBase):
         
         If it can't find any then returns None.
         
-        :return: :class:`~oyProjectManager.core.models.Version`
+        :return: :class:`~oyProjectManager.models.version.Version`
         """
         
         version = None
         
         # pm.env.sceneName() always uses "/"
         full_path = pm.env.sceneName()
-        
+        logger.debug('full_path : %s' % full_path)
         # try to get it from the current open scene
         if full_path != '':
             logger.debug("trying to get the version from current file")
@@ -334,12 +349,12 @@ class Maya(EnvironmentBase):
     
     def get_version_from_recent_files(self):
         """It will try to create a
-        :class:`~oyProjectManager.core.models.Version` instance by looking at
+        :class:`~oyProjectManager.models.version.Version` instance by looking at
         the recent files list.
         
         It will return None if it can not find one.
         
-        :return: :class:`~oyProjectManager.core.models.Version`
+        :return: :class:`~oyProjectManager.models.version.Version`
         """
 
         version = None
@@ -379,7 +394,7 @@ class Maya(EnvironmentBase):
           its path
         * Still not able to find any Version instances returns None
         
-        :returns: :class:`~oyProjectManager.core.models.Version` instance or
+        :returns: :class:`~oyProjectManager.models.version.Version` instance or
             None
         """
         
@@ -405,7 +420,7 @@ class Maya(EnvironmentBase):
         
         # image folder from the workspace.mel
         # {{project.full_path}}/Sequences/{{seqence.code}}/Shots/{{shot.code}}/.maya_files/RENDERED_IMAGES
-        image_folder_from_ws = pm.workspace.fileRules['image'] 
+        image_folder_from_ws = pm.workspace.fileRules['images'] 
         image_folder_from_ws_full_path = os.path.join(
             os.path.dirname(version.path),
             image_folder_from_ws
@@ -423,18 +438,12 @@ class Maya(EnvironmentBase):
         
         # convert the render_file_full_path to a relative path to the
         # imageFolderFromWS_full_path
-        
-#        print "imageFolderFromWS_full_path: %s" % image_folder_from_ws_full_path
-#        print "render_file_full_path: %s" % render_file_full_path
-
         render_file_rel_path = utils.relpath(
             image_folder_from_ws_full_path,
             render_file_full_path,
             sep="/"
         )
         
-#        print "render_file_rel_path: %s" % render_file_rel_path
-        
         if self.has_stereo_camera():
             # just add the <Camera> template variable to the file name
             render_file_rel_path += "_<Camera>"
@@ -447,7 +456,7 @@ class Maya(EnvironmentBase):
         dRG.setAttr('renderVersion', "v%03d" % version.version_number )
         dRG.setAttr('animation', 1)
         dRG.setAttr('outFormatControl', 0 )
-        dRG.setAttr('extensionPadding', 3 )
+        dRG.setAttr('extensionPadding', 4 )
         dRG.setAttr('imageFormat', 7 ) # force the format to iff
         dRG.setAttr('pff', 1)
         
@@ -544,14 +553,11 @@ class Maya(EnvironmentBase):
     def set_project(self, version):
         """Sets the project to the given version.
         
-        The Maya version uses :class:`~oyProjectManager.core.models.Version`
+        The Maya version uses :class:`~oyProjectManager.models.version.Version`
         instances to set the project. Because the Maya workspace is related to
         the the Asset or Shot which can be derived from the Version instance
         very easily.
         """
-        
-        # TODO: remove this method and the inherited one from the super
-        
         pm.workspace.open(
             os.path.dirname(
                 version.path
@@ -577,6 +583,76 @@ class Maya(EnvironmentBase):
         #assert(isinstance(recentFiles,pm.OptionVarList))
         recentFiles.appendVar( path )
     
+    def check_external_files(self):
+        """checks for external files in the current scene and raises
+        RuntimeError if there are local files in the current scene, used as:
+            
+            - File Textures
+            - Mentalray Textures
+            - ImagePlanes
+            - IBL nodes
+            - References
+        """
+        
+        def is_in_repo(path):
+            """checks if the given path is in repository
+            :param path: the path which wanted to be checked
+            :return: True or False
+            """
+            assert isinstance(path, (str, unicode))
+            path = os.path.expandvars(path)
+            return path.startswith(
+                os.environ[conf.repository_env_key].replace('\\', '/')
+            )
+        
+        external_nodes = []
+        
+        # check for file textures
+        for file_texture in pm.ls(type=pm.nt.File):
+            path = file_texture.attr('fileTextureName').get()
+            logger.debug('checking path: %s' % path)
+            if path is not None \
+               and os.path.isabs(path) \
+               and not is_in_repo(path):
+                logger.debug('is not in repo: %s' % path)
+                external_nodes.append(file_texture)
+        
+        # check for mentalray textures
+        for mr_texture in pm.ls(type=pm.nt.MentalrayTexture):
+            path = mr_texture.attr('fileTextureName').get()
+            logger.debug("path of %s: %s" % (mr_texture, path))
+            if path is not None \
+               and os.path.isabs(path) \
+               and not is_in_repo(path):
+                external_nodes.append(mr_texture)
+        
+        # check for ImagePlanes
+        for image_plane in pm.ls(type=pm.nt.ImagePlane):
+            path = image_plane.attr('imageName').get()
+            if path is not None \
+               and os.path.isabs(path) \
+               and not is_in_repo(path):
+                external_nodes.append(image_plane)
+        
+        # check for IBL nodes
+        for ibl in pm.ls(type=pm.nt.MentalrayIblShape):
+            path = ibl.attr('texture').get()
+            if path is not None \
+               and os.path.isabs(path) \
+               and not is_in_repo(path):
+                external_nodes.append(ibl)
+        
+        if external_nodes:
+            pm.select(external_nodes)
+            raise RuntimeError(
+                'There are external references in your scene!!!\n\n'
+                'The problematic nodes are:\n\n' +
+                "\n\t".join(map(lambda x: x.name(), external_nodes)) +
+                '\n\nThese nodes are added in to your selection list,\n'
+                'Please correct them!\n\n'
+                'YOUR FILE IS NOT GOING TO BE SAVED!!!'
+            )
+    
     def check_referenced_versions(self):
         """checks the referenced assets versions
         
@@ -648,11 +724,10 @@ class Maya(EnvironmentBase):
                 )
             else:
                 # try to get a version with the given path
-#                temp_version =\
-#                db.query(Version).filter(Version.full_path==full_path).first()
                 temp_version = self.get_version_from_full_path(full_path)
                 
                 if temp_version:
+                    # TODO: don't use the full_path here, it can be get from version instance itself
                     valid_versions.append((temp_version, reference, full_path))
                     
                     prev_version = temp_version
@@ -661,11 +736,11 @@ class Maya(EnvironmentBase):
         # return a sorted list
         return sorted(valid_versions, None, lambda x: x[2])
     
-    def update_references_list(self):
+    def update_references_list(self, version=None):
         """updates the references list of the current version
+        :param version: the version to be checked
         """
-        
-        version = self.get_current_version()
+        #version = self.get_current_version()
         
         if version is not None:
             # update the reference list
@@ -686,6 +761,7 @@ class Maya(EnvironmentBase):
         repo_env_key = "$" + conf.repository_env_key
         
         previous_version_full_path = ''
+        latest_version = None
         
         for version_tuple in version_tuple_list:
             version = version_tuple[0]
@@ -724,7 +800,7 @@ class Maya(EnvironmentBase):
         dRG = pm.PyNode('defaultRenderGlobals')
         dRG.setAttr('startFrame', start_frame )
         dRG.setAttr('endFrame', end_frame )
-    
+
     def get_fps(self):
         """returns the fps of the environment
         """
@@ -933,6 +1009,11 @@ class Maya(EnvironmentBase):
         
         workspace_path = pm.workspace.path
         
+        # fix for paths like S:/ (ending with a slash) for $REPO
+        server_path = os.environ[conf.repository_env_key]
+        if server_path.endswith('/'):
+            server_path = server_path[:-1]
+
         # replace reference paths with $REPO
         for ref in pm.listReferences():
             unresolved_path = ref.unresolvedPath().replace("\\", "/")
@@ -946,14 +1027,13 @@ class Maya(EnvironmentBase):
                         unresolved_path
                     )
                 
-                if unresolved_path.startswith(repo.server_path):
-    
+                if unresolved_path.startswith(server_path):
                     new_ref_path = ""
                     
                     if mode:
                         # convert to absolute path
                         new_ref_path = ref.path.replace(
-                            repo.server_path,
+                            server_path,
                             repo_env_key
                         )
                     else:
@@ -976,12 +1056,18 @@ class Maya(EnvironmentBase):
             
             logger.info("replacing file texture: %s" % file_texture_path)
             
-            file_texture_path = os.path.expandvars(file_texture_path)
+            file_texture_path = os.path.normpath(
+                os.path.expandvars(
+                    file_texture_path
+                )
+            )
+            file_texture_path = file_texture_path.replace("\\", "/")
             
             # convert to absolute
             if not os.path.isabs(file_texture_path):
                 file_texture_path = os.path.join(
-                    workspace_path, file_texture_path
+                    workspace_path,
+                    file_texture_path
                 ).replace("\\", "/")
             
             new_path = ""
@@ -989,7 +1075,7 @@ class Maya(EnvironmentBase):
             if mode:
                 # convert to absolute
                 new_path = file_texture_path.replace(
-                    os.environ[conf.repository_env_key],
+                    server_path,
                     "$" + conf.repository_env_key
                 )
             else:
@@ -999,10 +1085,6 @@ class Maya(EnvironmentBase):
                     file_texture_path,
                     "/", ".."
                 )
-#                new_path = new_path.replace(
-#                    os.environ[conf.repository_env_key],
-#                    "$" + conf.repository_env_key
-#                )
             
             logger.info("with: %s" % new_path)
             
@@ -1012,79 +1094,39 @@ class Maya(EnvironmentBase):
         """creates the workspace.mel at the given path
         """
         
-        content = """//Maya 2012 Project Definition
-
-workspace -fr "3dPaintTextures" ".maya_files/PAINTINGS/TEXTURES/";
-workspace -fr "Adobe(R) Illustrator(R)" ".maya_files/OTHERS/data/";
-workspace -fr "aliasWire" ".maya_files/OTHERS/data/";
-workspace -fr "animImport" ".maya_files/OTHERS/data/";
-workspace -fr "animExport" ".maya_files/OTHERS/data/";
-workspace -fr "audio" ".maya_files/EDIT/SOUND/";
-workspace -fr "autoSave" ".maya_files/OTHERS/autosave/";
-workspace -fr "clips" ".maya_files/OTHERS/clips/";
-workspace -fr "DAE_FBX" ".maya_files/OTHERS/data/";
-workspace -fr "DAE_FBX export" ".maya_files/OTHERS/data/";
-workspace -fr "depth" ".maya_files/RENDERED_IMAGES/renderData/depth/";
-workspace -fr "diskCache" ".maya_files/OTHERS/data/";
-workspace -fr "DXF" ".maya_files/OTHERS/data/";
-workspace -fr "DXF export" ".maya_files/OTHERS/data/";
-workspace -fr "DXF_FBX" ".maya_files/OTHERS/data/";
-workspace -fr "DXF_FBX export" ".maya_files/OTHERS/data/";
-workspace -fr "eps" ".maya_files/OTHERS/data/";
-workspace -fr "EPS" ".maya_files/OTHERS/data/";
-workspace -fr "FBX" ".maya_files/OTHERS/data/";
-workspace -fr "FBX export" ".maya_files/OTHERS/data/";
-workspace -fr "fluidCache" ".maya_files/OTHERS/cache/";
-workspace -fr "furAttrMap" ".maya_files/OTHERS/fur/furAttrMap/";
-workspace -fr "furEqualMap" ".maya_files/OTHERS/fur/furEqualMap/";
-workspace -fr "furFiles" ".maya_files/OTHERS/fur/furFiles/";
-workspace -fr "furImages" ".maya_files/OTHERS/fur/furImages/";
-workspace -fr "furShadowMap" ".maya_files/OTHERS/fur/furShadowMap/";
-workspace -fr "IGES" ".maya_files/OTHERS/data/";
-workspace -fr "IGESexport" ".maya_files/OTHERS/data/";
-workspace -fr "illustrator" ".maya_files/OTHERS/data/";
-workspace -fr "image" ".maya_files/RENDERED_IMAGES/";
-workspace -fr "images" ".maya_files/RENDERED_IMAGES/";
-workspace -fr "iprImages" ".maya_files/RENDERED_IMAGES/renderData/iprImages/";
-workspace -fr "lights" ".maya_files/RENDERED_IMAGES/renderData/shaders/";
-workspace -fr "mayaAscii" ".maya_files/OTHERS/";
-workspace -fr "mayaBinary" ".maya_files/OTHERS/";
-workspace -fr "mel" ".maya_files/OTHERS/mel/";
-workspace -fr "mentalray" ".maya_files/RENDERED_IMAGES/renderData/mentalRay/";
-workspace -fr "mentalRay" ".maya_files/RENDERED_IMAGES/renderData/mentalRay/";
-workspace -fr "move" ".maya_files/OTHERS/data/";
-workspace -fr "movie" ".maya_files/OTHERS/data/";
-workspace -fr "OBJ" ".maya_files/OTHERS/data/";
-workspace -fr "OBJexport" ".maya_files/OTHERS/data/";
-workspace -fr "offlineEdit" ".maya_files/OHTERS/edits/";
-workspace -fr "particles" ".maya_files/OTHERS/particles/";
-workspace -fr "renderData" ".maya_files/LIGHTING/";
-workspace -fr "renderScenes" ".maya_files/LIGHTING/";
-workspace -fr "RIB" ".maya_files/OTHERS/data/";
-workspace -fr "RIBexport" ".maya_files/OTHERS/data/";
-workspace -fr "scene" ".maya_files/OTHERS/";
-workspace -fr "scripts" ".maya_files/OTHERS/mel/";
-workspace -fr "shaders" ".maya_files/RENDERED_IMAGES";
-workspace -fr "sound" ".maya_files/OTHERS/sound/";
-workspace -fr "sourceImages" ".maya_files/PAINTINGS/TEXTURES/";
-workspace -fr "templates" ".maya_files/OTHERS/assets/";
-workspace -fr "textures" ".maya_files/PAINTINGS/TEXTURES/";
-workspace -fr "translatorData" ".maya_files/OTHERS/";
-        """
+        content = conf.maya_workspace_file_content
         
         # check if there is a workspace.mel at the given path
         full_path = os.path.join(path, "workspace.mel")
         
-        if not os.path.exists(full_path):
+        #if not os.path.exists(full_path):
+        try:
+            os.makedirs(
+                os.path.dirname(full_path)
+            )
+        except OSError:
+            # dir exists
+            pass
+                
+        workspace_file = file(full_path, "w")
+        workspace_file.write(content)
+        workspace_file.close()
+        
+    
+    def create_workspace_folders(self, path):
+        """creates the workspace folders
+        :param path: the root of the workspace
+        """
+        
+        for key in pm.workspace.fileRules:
+            rule_path = pm.workspace.fileRules[key]
+            full_path = os.path.join(path, rule_path)
+            print full_path
             try:
                 os.makedirs(
-                    os.path.dirname(full_path)
+                    full_path
                 )
             except OSError:
                 # dir exists
                 pass
-                
-            workspace_file = file(full_path, "w")
-            workspace_file.write(content)
-            workspace_file.close()
-    
+        
