@@ -4,19 +4,31 @@
 # This module is part of oyProjectManager and is released under the BSD 2
 # License: http://www.opensource.org/licenses/BSD-2-Clause
 
+import os
 import sys
 
-#from PySide import QtGui, QtCore
-import sip
-sip.setapi('QString', 2)
-sip.setapi('QVariant', 2)
-from PyQt4 import QtGui, QtCore
-
 import oyProjectManager
 from oyProjectManager import db
-from oyProjectManager.ui import project_properties
-import project_manager_UI
-from oyProjectManager.core.models import Project, Sequence, Shot
+from oyProjectManager.models.project import Project
+from oyProjectManager.models.sequence import Sequence
+from oyProjectManager.models.shot import Shot
+from oyProjectManager.ui import project_properties, shot_editor
+
+qt_module_key = "PREFERRED_QT_MODULE"
+qt_module = "PyQt4"
+
+if os.environ.has_key(qt_module_key):
+    qt_module = os.environ[qt_module_key]
+
+if qt_module == "PySide":
+    from PySide import QtGui, QtCore
+    from oyProjectManager.ui import project_manager_UI_pyside as project_manager_UI
+elif qt_module == "PyQt4":
+    import sip
+    sip.setapi('QString', 2)
+    sip.setapi('QVariant', 2)
+    from PyQt4 import QtGui, QtCore
+    from oyProjectManager.ui import project_manager_UI_pyqt4 as project_manager_UI
 
 def UI():
     """the UI to call the dialog by itself
@@ -26,14 +38,16 @@ def UI():
     
     self_quit = False
     if QtGui.QApplication.instance() is None:
-        app = QtGui.QApplication(sys.argv)
+        try:
+            app = QtGui.QApplication(sys.argv)
+        except AttributeError: # sys.argv gives argv.error
+            app = QtGui.QApplication([])
         self_quit = True
     else:
         app = QtGui.QApplication.instance()
     
     mainDialog = MainDialog()
     mainDialog.show()
-    #app.setStyle('Plastique')
     app.exec_()
 
     if self_quit:
@@ -46,7 +60,6 @@ def UI():
 
     return mainDialog
 
-
 class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
     """the main dialog of the system
     """
@@ -68,7 +81,7 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
         self.projects_comboBox.projects = []
         self.sequences_comboBox.sequences = []
         self.shots_comboBox.shots = []
-
+        
         # setup the database
         if db.session is None:
             db.setup()
@@ -132,12 +145,26 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
             self.new_sequence_pushButton_clicked
         )
         
+        # edit_shot_pushButton
+        QtCore.QObject.connect(
+            self.edit_shot_pushButton,
+            QtCore.SIGNAL('clicked()'),
+            self.edit_shot_pushButton_clicked
+        )
+        
         # new_shots_pushButton
         QtCore.QObject.connect(
             self.new_shots_pushButton,
             QtCore.SIGNAL("clicked()"),
             self.new_shots_pushButton_clicked
         )
+        
+        # create_project_structure_pushButton
+        QtCore.QObject.connect(
+            self.create_project_structure_pushButton,
+            QtCore.SIGNAL("clicked()"),
+            self.create_project_structure
+        )
 
     def _set_defaults(self):
         """sets the default values for the interface
@@ -154,7 +181,7 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
         """
         
         # fill projects
-        projects = db.query(Project)\
+        projects = Project.query()\
             .order_by(Project.name.asc())\
             .all()
 
@@ -162,7 +189,17 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
         self.projects_comboBox.projects = projects
         
         self.projects_comboBox.clear()
-        self.projects_comboBox.addItems(map(lambda x: x.name, projects))
+        #self.projects_comboBox.addItems(map(lambda x: x.name, projects))
+        for i, project in enumerate(projects):
+            if project.active:
+                self.projects_comboBox.addItem(project.name)
+            else:
+                self.projects_comboBox.addItem(
+                    QtGui.QIcon(
+                        ":/trolltech/styles/commonstyle/images/stop-24.png"
+                    ),
+                    project.name
+                )
     
     def projects_changed(self):
         """runs when the projects comboBox changed
@@ -173,7 +210,7 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
         """updates the sequences_comboBox according to the current project
         """
         project = self.get_current_project()
-        sequences = db.query(Sequence)\
+        sequences = Sequence.query()\
             .filter(Sequence.project==project)\
             .order_by(Sequence.name.asc())\
             .all()
@@ -183,9 +220,9 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
     
     def get_current_project(self):
         """Returns the currently selected
-        :class:`~oyProjectManager.core.models.Project` instance from the UI
+        :class:`~oyProjectManager.models.project.Project` instance from the UI
         
-        :return: :class:`~oyProjectManager.core.models.Project`
+        :return: :class:`~oyProjectManager.models.project.Project`
         """
         
         index = self.projects_comboBox.currentIndex()
@@ -207,7 +244,7 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
         """
         
         sequence = self.get_current_sequence()
-        shots = db.query(Shot)\
+        shots = Shot.query()\
             .filter(Shot.sequence==sequence)\
             .order_by(Shot.code.asc())\
             .all()
@@ -220,17 +257,24 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
     
     def get_current_sequence(self):
         """Returns the currently selected
-        :class:`~oyProjectManager.core.models.Sequence` instance from the UI
+        :class:`~oyProjectManager.models.sequence.Sequence` instance from the UI
         
-        :return: :class:`~oyProjectManager.core.models.Sequence`
+        :return: :class:`~oyProjectManager.models.sequence.Sequence`
         """
         
         index = self.sequences_comboBox.currentIndex()
         if index != -1:
             return self.sequences_comboBox.sequences[index]
-        
         return None
-
+    
+    def get_current_shot(self):
+        """Returns the currently selected Shot instance fom the UI
+        """
+        index = self.shots_comboBox.currentIndex()
+        if index != -1:
+            return self.shots_comboBox.shots[index]
+        return None
+    
     def new_project_pushButton_clicked(self):
         """runs when new_project_pushButton is clicked
         """
@@ -297,10 +341,19 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
                 index = self.sequences_comboBox.findText(new_sequence.name)
                 self.sequences_comboBox.setCurrentIndex(index)
     
+    def edit_shot_pushButton_clicked(self):
+        """runs when the edit_shot_pushButton is clicked
+        """
+        shot = self.get_current_shot()
+        
+        if shot:
+            # create the shot_editor dialog
+            dialog = shot_editor.MainDialog(shot, self)
+            dialog.exec_()
+    
     def new_shots_pushButton_clicked(self):
         """runs when new_shots_pushButton clicked
         """
-        
         sequence = self.get_current_sequence()
         
         if sequence is None:
@@ -322,3 +375,12 @@ class MainDialog(QtGui.QDialog, project_manager_UI.Ui_dialog):
                 
                 # update the shots_comboBox
                 self.update_shots_comboBox()
+    
+    def create_project_structure(self):
+        """runs when the create_project_structure_pushButton has been clicked
+        """
+        
+        proj = self.get_current_project()
+        
+        if proj:
+            proj.create()
