@@ -14,18 +14,19 @@ import unittest
 #from PySide.QtCore import Qt
 #from PySide.QtTest import QTest
 import sip
+from oyProjectManager.models.project import Project
+from oyProjectManager.models.sequence import Sequence
+from oyProjectManager.models.shot import Shot
+
 sip.setapi('QString', 2)
 sip.setapi('QVariant', 2)
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import Qt
 from PyQt4.QtTest import QTest
 
-from oyProjectManager import config, db
-from oyProjectManager.core.models import (Project, Sequence, Shot)
+from oyProjectManager import conf, db
 from oyProjectManager.ui import project_manager
 
-conf = config.Config()
-
 class ProjectManager_Tester(unittest.TestCase):
     """tests the oyProjectManager.ui.project_manager
     """
@@ -35,6 +36,8 @@ class ProjectManager_Tester(unittest.TestCase):
         """
         # -----------------------------------------------------------------
         # start of the setUp
+        conf.database_url = "sqlite://"
+        
         # create the environment variable and point it to a temp directory
         self.temp_config_folder = tempfile.mkdtemp()
         self.temp_projects_folder = tempfile.mkdtemp()
@@ -81,13 +84,15 @@ class ProjectManager_Tester(unittest.TestCase):
         project2 = Project("Test Project 2")
         project3 = Project("Test Project 3")
         
+        project3.active = False
+        
         project1.save()
         project2.save()
         project3.save()
         
         # open UI
         dialog = project_manager.MainDialog()
-#        self.show_dialod(dialog)
+        #self.show_dialog(dialog)
 
         
         # check if the projects are listed there
@@ -381,7 +386,7 @@ class ProjectManager_Tester(unittest.TestCase):
         # check if there is no shot folder
         project_path = os.path.join(
             self.temp_projects_folder,
-            "TEST_PROJECT/Sequences/SEQUENCE/Shots/SH001"
+            "Test_Project/Shots/SH001"
         )
         
         self.assertFalse(
@@ -390,7 +395,7 @@ class ProjectManager_Tester(unittest.TestCase):
             )
         )
         
-        # hit create_stucture_pushButton
+        # hit create_structure_pushButton
         dialog = project_manager.MainDialog()
         
         QTest.mouseClick(
